@@ -23,13 +23,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from os import stat
-from os.path import exists
+from os.path import exists, getsize
 import sys
 import glob
 import string
 from optparse import OptionParser
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
+
 
 class Pygtail(object):
     """
@@ -44,17 +45,21 @@ class Pygtail(object):
         self._fh = None
         self._rotated_logfile = None
 
-        # if offset file exists, open and parse it
-        if exists(self._offset_file):
+        # if offset file exists and non-empty, open and parse it
+        if exists(self._offset_file) and getsize(self._offset_file):
             offset_fh = open(self._offset_file, "r")
             (self._offset_file_inode, self._offset) = \
-                [string.atoi(line.strip()) for line in offset_fh]
+                [int(line.strip()) for line in offset_fh]
             offset_fh.close()
             if self._offset_file_inode != stat(self.filename).st_ino:
                 # The inode has changed, so the file might have been rotated.
                 # Look for the rotated file and process that if we find it.
                 self._rotated_logfile = self._determine_rotated_logfile()
 
+    def __del__(self):
+        if self._filehandle():
+            self._filehandle().close()
+
     def __iter__(self):
         return self
 
@@ -63,7 +68,7 @@ class Pygtail(object):
         Return the next line in the file, updating the offset.
         """
         try:
-            line = self._filehandle().next()
+            line = next(self._filehandle())
         except StopIteration:
             # we've reached the end of the file; if we're processing the
             # rotated log file, we can continue with the actual file; otherwise
@@ -74,8 +79,8 @@ class Pygtail(object):
                 self._offset = 0
                 # open up current logfile and continue
                 try:
-                    line = self._filehandle().next()
-                except StopIteration: # oops, empty file
+                    line = next(self._filehandle())
+                except StopIteration:  # oops, empty file
                     self._update_offset_file()
                     raise
             else:
@@ -87,6 +92,10 @@ class Pygtail(object):
 
         return line
 
+    def __next__(self):
+        """`__next__` is the Python 3 version of `next`"""
+        return self.next()
+
     def readlines(self):
         """
         Read in all unread lines and return them as a list.
@@ -157,11 +166,18 @@ class Pygtail(object):
         candidates = glob.glob("%s-[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]" % self.filename)
         if candidates:
             candidates.sort()
-            return candidates[-1] # return most recent
+            return candidates[-1]  # return most recent
+
+        # for TimedRotatingFileHandler
+        candidates = glob.glob("%s.[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]" % self.filename)
+        if candidates:
+            candidates.sort()
+            return candidates[-1]  # return most recent
 
         # no match
         return None
 
+
 def main():
     # command-line parsing
     cmdline = OptionParser(usage="usage: %prog [options] logfile",
@@ -177,8 +193,8 @@ def main():
     if (len(args) != 1):
         cmdline.error("Please provide a logfile to read.")
 
-    pygtail = Pygtail(args[0], 
-                      offset_file=options.offset_file, 
+    pygtail = Pygtail(args[0],
+                      offset_file=options.offset_file,
                       paranoid=options.paranoid)
     for line in pygtail:
         sys.stdout.write(line)
